@@ -1,16 +1,14 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
 DOCUMENTATION = r"""
 ---
 module: credential_to_site_by_siteid_create_v2
 short_description: Resource module for Credential To Site By Siteid Create V2
 description:
-- Manage operation create of the resource Credential To Site By Siteid Create V2.
-- API to assign Device Credential to a site.
+  - Manage operation create of the resource Credential To Site By Siteid Create V2.
+  - API to assign Device Credential to a site.
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module
@@ -38,21 +36,16 @@ options:
     description: SNMPv3 Credential Id.
     type: str
 requirements:
-- dnacentersdk >= 2.4.9
-- python >= 3.5
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Network Settings AssignDeviceCredentialToSiteV2
-  description: Complete reference of the AssignDeviceCredentialToSiteV2 API.
-  link: https://developer.cisco.com/docs/dna-center/#!assign-device-credential-to-site-v-2
+  - name: Cisco DNA Center documentation for Network Settings AssignDeviceCredentialToSiteV2
+    description: Complete reference of the AssignDeviceCredentialToSiteV2 API.
+    link: https://developer.cisco.com/docs/dna-center/#!assign-device-credential-to-site
 notes:
-  - SDK Method used are
-    network_settings.NetworkSettings.assign_device_credential_to_site_v2,
-
-  - Paths used are
-    post /dna/intent/api/v2/credential-to-site/{siteId},
-
+  - SDK Method used are network_settings.NetworkSettings.assign_device_credential_to_site_v2,
+  - Paths used are post /dna/intent/api/v2/credential-to-site/{siteId},
 """
-
 EXAMPLES = r"""
 - name: Create
   cisco.dnac.credential_to_site_by_siteid_create_v2:
@@ -70,7 +63,6 @@ EXAMPLES = r"""
     snmpV2ReadId: string
     snmpV2WriteId: string
     snmpV3Id: string
-
 """
 RETURN = r"""
 dnac_response:
