@@ -3,9 +3,8 @@
 # Copyright (c) 2018 Ansible Project
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
-from __future__ import (absolute_import, division, print_function)
+from __future__ import annotations
 
-__metaclass__ = type
 
 DOCUMENTATION = '''
     name: proxmox
@@ -25,7 +24,7 @@ DOCUMENTATION = '''
         - inventory_cache
     options:
       plugin:
-        description: The name of this plugin, it should always be set to V(community.general.proxmox) for this plugin to recognize it as it's own.
+        description: The name of this plugin, it should always be set to V(community.general.proxmox) for this plugin to recognize it as its own.
         required: true
         choices: ['community.general.proxmox']
         type: str
@@ -138,6 +137,7 @@ DOCUMENTATION = '''
 '''
 
 EXAMPLES = '''
+---
 # Minimal example which will not gather additional facts for QEMU/LXC guests
 # By not specifying a URL the plugin will attempt to connect to the controller host on port 8006
 # my.proxmox.yml
@@ -148,13 +148,18 @@ password: secure
 # an example where this is set to `false` and where ansible_host is set with `compose`.
 want_proxmox_nodes_ansible_host: true
 
+---
 # Instead of login with password, proxmox supports api token authentication since release 6.2.
 plugin: community.general.proxmox
 user: ci@pve
 token_id: gitlab-1
 token_secret: fa256e9c-26ab-41ec-82da-707a2c079829
 
+---
 # The secret can also be a vault string or passed via the environment variable TOKEN_SECRET.
+plugin: community.general.proxmox
+user: ci@pve
+token_id: gitlab-1
 token_secret: !vault |
           $ANSIBLE_VAULT;1.1;AES256
           62353634333163633336343265623632626339313032653563653165313262343931643431656138
@@ -164,6 +169,7 @@ token_secret: !vault |
           32643131386134396336623736393634373936356332623632306561356361323737313663633633
           6231313333666361656537343562333337323030623732323833
 
+---
 # More complete example demonstrating the use of 'want_facts' and the constructed options
 # Note that using facts returned by 'want_facts' in constructed options requires 'want_facts=true'
 # my.proxmox.yml
@@ -186,6 +192,7 @@ compose:
 # an example where this is set to `false` and where ansible_host is set with `compose`.
 want_proxmox_nodes_ansible_host: true
 
+---
 # Using the inventory to allow ansible to connect via the first IP address of the VM / Container
 # (Default is connection by name of QEMU/LXC guests)
 # Note: my_inv_var demonstrates how to add a string variable to every host used by the inventory.
@@ -203,6 +210,7 @@ compose:
   my_inv_var_2: >
     "my_var_2_value"
 
+---
 # Specify the url, user and password using templating
 # my.proxmox.yml
 plugin: community.general.proxmox
@@ -212,7 +220,6 @@ password: "{{ lookup('community.general.random_string', base64=True) }}"
 # Note that this can easily give you wrong values as ansible_host. See further up for
 # an example where this is set to `false` and where ansible_host is set with `compose`.
 want_proxmox_nodes_ansible_host: true
-
 '''
 
 import itertools
@@ -222,7 +229,6 @@ from ansible.module_utils.common._collections_compat import MutableMapping
 
 from ansible.errors import AnsibleError
 from ansible.plugins.inventory import BaseInventoryPlugin, Constructable, Cacheable
-from ansible.module_utils.common.text.converters import to_native
 from ansible.module_utils.six import string_types
 from ansible.module_utils.six.moves.urllib.parse import urlencode
 from ansible.utils.display import Display
@@ -275,7 +281,6 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
         return self.session
 
     def _get_auth(self):
-
         validate_certs = self.get_option('validate_certs')
 
         if validate_certs is False:
@@ -283,33 +288,40 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
             disable_warnings()
 
         if self.proxmox_password:
-
             credentials = urlencode({'username': self.proxmox_user, 'password': self.proxmox_password})
-
             a = self._get_session()
-
-            ret = a.post('%s/api2/json/access/ticket' % self.proxmox_url, data=credentials)
-
+            ret = a.post(f'{self.proxmox_url}/api2/json/access/ticket', data=credentials)
             json = ret.json()
-
             self.headers = {
                 # only required for POST/PUT/DELETE methods, which we are not using currently
                 # 'CSRFPreventionToken': json['data']['CSRFPreventionToken'],
-                'Cookie': 'PVEAuthCookie={0}'.format(json['data']['ticket'])
+                'Cookie': f"PVEAuthCookie={json['data']['ticket']}"
             }
-
         else:
+            # Clean and format token components
+            user = self.proxmox_user.strip()
+            token_id = self.proxmox_token_id.strip()
+            token_secret = self.proxmox_token_secret.strip()
 
-            self.headers = {'Authorization': 'PVEAPIToken={0}!{1}={2}'.format(self.proxmox_user, self.proxmox_token_id, self.proxmox_token_secret)}
+            # Build token string without newlines
+            token = f'{user}!{token_id}={token_secret}'
+
+            # Set headers with clean token
+            self.headers = {'Authorization': f'PVEAPIToken={token}'}
 
     def _get_json(self, url, ignore_errors=None):
 
-        if not self.use_cache or url not in self._cache.get(self.cache_key, {}):
+        data = []
+        has_data = False
 
-            if self.cache_key not in self._cache:
-                self._cache[self.cache_key] = {'url': ''}
+        if self.use_cache:
+            try:
+                data = self._cache[self.cache_key][url]
+                has_data = True
+            except KeyError:
+                self.update_cache = True
 
-            data = []
+        if not has_data:
             s = self._get_session()
             while True:
                 ret = s.get(url, headers=self.headers)
@@ -335,34 +347,48 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
                         data = data + json['data']
                     break
 
-            self._cache[self.cache_key][url] = data
-
-        return make_unsafe(self._cache[self.cache_key][url])
+        self._results[url] = data
+        return make_unsafe(data)
 
     def _get_nodes(self):
-        return self._get_json("%s/api2/json/nodes" % self.proxmox_url)
+        return self._get_json(f"{self.proxmox_url}/api2/json/nodes")
 
     def _get_pools(self):
-        return self._get_json("%s/api2/json/pools" % self.proxmox_url)
+        return self._get_json(f"{self.proxmox_url}/api2/json/pools")
 
     def _get_lxc_per_node(self, node):
-        return self._get_json("%s/api2/json/nodes/%s/lxc" % (self.proxmox_url, node))
+        return self._get_json(f"{self.proxmox_url}/api2/json/nodes/{node}/lxc")
 
     def _get_qemu_per_node(self, node):
-        return self._get_json("%s/api2/json/nodes/%s/qemu" % (self.proxmox_url, node))
+        return self._get_json(f"{self.proxmox_url}/api2/json/nodes/{node}/qemu")
 
     def _get_members_per_pool(self, pool):
-        ret = self._get_json("%s/api2/json/pools/%s" % (self.proxmox_url, pool))
+        ret = self._get_json(f"{self.proxmox_url}/api2/json/pools/{pool}")
         return ret['members']
 
     def _get_node_ip(self, node):
-        ret = self._get_json("%s/api2/json/nodes/%s/network" % (self.proxmox_url, node))
+        ret = self._get_json(f"{self.proxmox_url}/api2/json/nodes/{node}/network")
+
+        # sort interface by iface name to make selection as stable as possible
+        ret.sort(key=lambda x: x['iface'])
 
         for iface in ret:
             try:
+                # only process interfaces adhering to these rules
+                if 'active' not in iface:
+                    self.display.vvv(f"Interface {iface['iface']} on node {node} does not have an active state")
+                    continue
+                if 'address' not in iface:
+                    self.display.vvv(f"Interface {iface['iface']} on node {node} does not have an address")
+                    continue
+                if 'gateway' not in iface:
+                    self.display.vvv(f"Interface {iface['iface']} on node {node} does not have a gateway")
+                    continue
+                self.display.vv(f"Using interface {iface['iface']} on node {node} with address {iface['address']} as node ip for ansible_host")
                 return iface['address']
             except Exception:
-                return None
+                continue
+        return None
 
     def _get_lxc_interfaces(self, properties, node, vmid):
         status_key = self._fact('status')
@@ -370,7 +396,7 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
         if status_key not in properties or not properties[status_key] == 'running':
             return
 
-        ret = self._get_json("%s/api2/json/nodes/%s/lxc/%s/interfaces" % (self.proxmox_url, node, vmid), ignore_errors=[501])
+        ret = self._get_json(f"{self.proxmox_url}/api2/json/nodes/{node}/lxc/{vmid}/interfaces", ignore_errors=[501])
         if not ret:
             return
 
@@ -397,15 +423,13 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
 
         try:
             ifaces = self._get_json(
-                "%s/api2/json/nodes/%s/%s/%s/agent/network-get-interfaces" % (
-                    self.proxmox_url, node, vmtype, vmid
-                )
+                f"{self.proxmox_url}/api2/json/nodes/{node}/{vmtype}/{vmid}/agent/network-get-interfaces"
             )['result']
 
             if "error" in ifaces:
                 if "class" in ifaces["error"]:
                     # This happens on Windows, even though qemu agent is running, the IP address
-                    # cannot be fetched, as it's unsupported, also a command disabled can happen.
+                    # cannot be fetched, as it is unsupported, also a command disabled can happen.
                     errorClass = ifaces["error"]["class"]
                     if errorClass in ["Unsupported"]:
                         self.display.v("Retrieving network interfaces from guest agents on windows with older qemu-guest-agents is not supported")
@@ -417,7 +441,7 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
                 result.append({
                     'name': iface['name'],
                     'mac-address': iface['hardware-address'] if 'hardware-address' in iface else '',
-                    'ip-addresses': ["%s/%s" % (ip['ip-address'], ip['prefix']) for ip in iface['ip-addresses']] if 'ip-addresses' in iface else []
+                    'ip-addresses': [f"{ip['ip-address']}/{ip['prefix']}" for ip in iface['ip-addresses']] if 'ip-addresses' in iface else []
                 })
         except requests.HTTPError:
             pass
@@ -425,7 +449,7 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
         return result
 
     def _get_vm_config(self, properties, node, vmid, vmtype, name):
-        ret = self._get_json("%s/api2/json/nodes/%s/%s/%s/config" % (self.proxmox_url, node, vmtype, vmid))
+        ret = self._get_json(f"{self.proxmox_url}/api2/json/nodes/{node}/{vmtype}/{vmid}/config")
 
         properties[self._fact('node')] = node
         properties[self._fact('vmid')] = vmid
@@ -441,13 +465,13 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
             try:
                 # fixup disk images as they have no key
                 if config == 'rootfs' or config.startswith(('virtio', 'sata', 'ide', 'scsi')):
-                    value = ('disk_image=' + value)
+                    value = f"disk_image={value}"
 
                 # Additional field containing parsed tags as list
                 if config == 'tags':
                     stripped_value = value.strip()
                     if stripped_value:
-                        parsed_key = key + "_parsed"
+                        parsed_key = f"{key}_parsed"
                         properties[parsed_key] = [tag.strip() for tag in stripped_value.replace(',', ';').split(";")]
 
                 # The first field in the agent string tells you whether the agent is enabled
@@ -463,7 +487,7 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
                     if agent_enabled:
                         agent_iface_value = self._get_agent_network_interfaces(node, vmid, vmtype)
                         if agent_iface_value:
-                            agent_iface_key = self.to_safe('%s%s' % (key, "_interfaces"))
+                            agent_iface_key = self.to_safe(f'{key}_interfaces')
                             properties[agent_iface_key] = agent_iface_value
 
                 if config == 'lxc':
@@ -488,13 +512,13 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
                 return None
 
     def _get_vm_status(self, properties, node, vmid, vmtype, name):
-        ret = self._get_json("%s/api2/json/nodes/%s/%s/%s/status/current" % (self.proxmox_url, node, vmtype, vmid))
+        ret = self._get_json(f"{self.proxmox_url}/api2/json/nodes/{node}/{vmtype}/{vmid}/status/current")
         properties[self._fact('status')] = ret['status']
         if vmtype == 'qemu':
             properties[self._fact('qmpstatus')] = ret['qmpstatus']
 
     def _get_vm_snapshots(self, properties, node, vmid, vmtype, name):
-        ret = self._get_json("%s/api2/json/nodes/%s/%s/%s/snapshot" % (self.proxmox_url, node, vmtype, vmid))
+        ret = self._get_json(f"{self.proxmox_url}/api2/json/nodes/{node}/{vmtype}/{vmid}/snapshot")
         snapshots = [snapshot['name'] for snapshot in ret if snapshot['name'] != 'current']
         properties[self._fact('snapshots')] = snapshots
 
@@ -508,11 +532,11 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
 
     def _fact(self, name):
         '''Generate a fact's full name from the common prefix and a name.'''
-        return self.to_safe('%s%s' % (self.facts_prefix, name.lower()))
+        return self.to_safe(f'{self.facts_prefix}{name.lower()}')
 
     def _group(self, name):
         '''Generate a group's full name from the common prefix and a name.'''
-        return self.to_safe('%s%s' % (self.group_prefix, name.lower()))
+        return self.to_safe(f'{self.group_prefix}{name.lower()}')
 
     def _can_add_host(self, name, properties):
         '''Ensure that a host satisfies all defined hosts filters. If strict mode is
@@ -524,7 +548,7 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
                 if not self._compose(host_filter, properties):
                     return False
             except Exception as e:  # pylint: disable=broad-except
-                message = "Could not evaluate host filter %s for host %s - %s" % (host_filter, name, to_native(e))
+                message = f"Could not evaluate host filter {host_filter} for host {name} - {e}"
                 if self.strict:
                     raise AnsibleError(message)
                 display.warning(message)
@@ -565,8 +589,8 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
 
         # add the host to the inventory
         self._add_host(name, properties)
-        node_type_group = self._group('%s_%s' % (node, ittype))
-        self.inventory.add_child(self._group('all_' + ittype), name)
+        node_type_group = self._group(f'{node}_{ittype}')
+        self.inventory.add_child(self._group(f"all_{ittype}"), name)
         self.inventory.add_child(node_type_group, name)
 
         item_status = item['status']
@@ -574,7 +598,7 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
             if want_facts and ittype == 'qemu' and self.get_option('qemu_extended_statuses'):
                 # get more details about the status of the qemu VM
                 item_status = properties.get(self._fact('qmpstatus'), item_status)
-        self.inventory.add_child(self._group('all_%s' % (item_status, )), name)
+        self.inventory.add_child(self._group(f'all_{item_status}'), name)
 
         return name
 
@@ -585,7 +609,7 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
             poolid = pool.get('poolid')
             if not poolid:
                 continue
-            pool_group = self._group('pool_' + poolid)
+            pool_group = self._group(f"pool_{poolid}")
             self.inventory.add_group(pool_group)
 
             for member in self._get_members_per_pool(poolid):
@@ -602,7 +626,7 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
             default_groups.extend(['prelaunch', 'paused'])
 
         for group in default_groups:
-            self.inventory.add_group(self._group('all_%s' % (group)))
+            self.inventory.add_group(self._group(f'all_{group}'))
         nodes_group = self._group('nodes')
         if not self.exclude_nodes:
             self.inventory.add_group(nodes_group)
@@ -635,7 +659,7 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
 
             # add LXC/Qemu groups for the node
             for ittype in ('lxc', 'qemu'):
-                node_type_group = self._group('%s_%s' % (node['node'], ittype))
+                node_type_group = self._group(f"{node['node']}_{ittype}")
                 self.inventory.add_group(node_type_group)
 
             # get LXC containers and Qemu VMs for this node
@@ -663,8 +687,8 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
         for o in ('url', 'user', 'password', 'token_id', 'token_secret'):
             v = self.get_option(o)
             if self.templar.is_template(v):
-                v = self.templar.template(v, disable_lookups=False)
-            setattr(self, 'proxmox_%s' % o, v)
+                v = self.templar.template(v)
+            setattr(self, f'proxmox_{o}', v)
 
         # some more cleanup and validation
         self.proxmox_url = self.proxmox_url.rstrip('/')
@@ -678,10 +702,14 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
         self.exclude_nodes = self.get_option('exclude_nodes')
         self.cache_key = self.get_cache_key(path)
         self.use_cache = cache and self.get_option('cache')
+        self.update_cache = not cache and self.get_option('cache')
         self.host_filters = self.get_option('filters')
         self.group_prefix = self.get_option('group_prefix')
         self.facts_prefix = self.get_option('facts_prefix')
         self.strict = self.get_option('strict')
 
         # actually populate inventory
+        self._results = {}
         self._populate()
+        if self.update_cache:
+            self._cache[self.cache_key] = self._results
