@@ -262,6 +262,13 @@ options:
                         choices:
                             - 'disable'
                             - 'enable'
+                    verify_cert:
+                        aliases: ['verify-cert']
+                        type: str
+                        description: Enable/disable certificate verification of the real server.
+                        choices:
+                            - 'disable'
+                            - 'enable'
             saml_server:
                 aliases: ['saml-server']
                 type: str
@@ -506,6 +513,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -522,71 +530,70 @@ EXAMPLES = '''
         access_proxy: <your own value>
         state: present # <value in [present, absent]>
         firewall_accessproxy_apigateway:
-          http_cookie_age: <integer>
-          http_cookie_domain: <string>
-          http_cookie_domain_from_host: <value in [disable, enable]>
-          http_cookie_generation: <integer>
-          http_cookie_path: <string>
-          http_cookie_share: <value in [disable, same-ip]>
-          https_cookie_secure: <value in [disable, enable]>
-          id: <integer>
-          ldb_method: <value in [static, round-robin, weighted, ...]>
-          persistence: <value in [none, http-cookie]>
-          realservers:
-            -
-              address: <string>
-              health_check: <value in [disable, enable]>
-              health_check_proto: <value in [ping, http, tcp-connect]>
-              http_host: <string>
-              id: <integer>
-              ip: <string>
-              mappedport: <list or string>
-              port: <integer>
-              status: <value in [active, standby, disable]>
-              weight: <integer>
-              addr_type: <value in [fqdn, ip]>
-              domain: <string>
-              holddown_interval: <value in [disable, enable]>
-              ssh_client_cert: <string>
-              ssh_host_key: <list or string>
-              ssh_host_key_validation: <value in [disable, enable]>
-              type: <value in [tcp-forwarding, ssh]>
-              translate_host: <value in [disable, enable]>
-              external_auth: <value in [disable, enable]>
-              tunnel_encryption: <value in [disable, enable]>
-          saml_server: <string>
-          service: <value in [http, https, tcp-forwarding, ...]>
-          ssl_algorithm: <value in [high, medium, low, ...]>
-          ssl_cipher_suites:
-            -
-              cipher: <value in [TLS-RSA-WITH-RC4-128-MD5, TLS-RSA-WITH-RC4-128-SHA, TLS-RSA-WITH-DES-CBC-SHA, ...]>
-              priority: <integer>
-              versions:
-                - "tls-1.0"
-                - "tls-1.1"
-                - "tls-1.2"
-                - "tls-1.3"
-          ssl_dh_bits: <value in [768, 1024, 1536, ...]>
-          ssl_max_version: <value in [tls-1.0, tls-1.1, tls-1.2, ...]>
-          ssl_min_version: <value in [tls-1.0, tls-1.1, tls-1.2, ...]>
-          url_map: <string>
-          url_map_type: <value in [sub-string, wildcard, regex]>
-          virtual_host: <string>
-          saml_redirect: <value in [disable, enable]>
-          ssl_vpn_web_portal: <string>
-          application: <list or string>
-          ssl_renegotiation: <value in [disable, enable]>
-          h2_support: <value in [disable, enable]>
-          h3_support: <value in [disable, enable]>
-          quic:
-            ack_delay_exponent: <integer>
-            active_connection_id_limit: <integer>
-            active_migration: <value in [disable, enable]>
-            grease_quic_bit: <value in [disable, enable]>
-            max_ack_delay: <integer>
-            max_datagram_frame_size: <integer>
-            max_idle_timeout: <integer>
-            max_udp_payload_size: <integer>
+          id: 0 # Required variable, integer
+          # http_cookie_age: <integer>
+          # http_cookie_domain: <string>
+          # http_cookie_domain_from_host: <value in [disable, enable]>
+          # http_cookie_generation: <integer>
+          # http_cookie_path: <string>
+          # http_cookie_share: <value in [disable, same-ip]>
+          # https_cookie_secure: <value in [disable, enable]>
+          # ldb_method: <value in [static, round-robin, weighted, ...]>
+          # persistence: <value in [none, http-cookie]>
+          # realservers:
+          #   - address: <string>
+          #     health_check: <value in [disable, enable]>
+          #     health_check_proto: <value in [ping, http, tcp-connect]>
+          #     http_host: <string>
+          #     id: <integer>
+          #     ip: <string>
+          #     mappedport: <list or string>
+          #     port: <integer>
+          #     status: <value in [active, standby, disable]>
+          #     weight: <integer>
+          #     addr_type: <value in [fqdn, ip]>
+          #     domain: <string>
+          #     holddown_interval: <value in [disable, enable]>
+          #     ssh_client_cert: <string>
+          #     ssh_host_key: <list or string>
+          #     ssh_host_key_validation: <value in [disable, enable]>
+          #     type: <value in [tcp-forwarding, ssh]>
+          #     translate_host: <value in [disable, enable]>
+          #     external_auth: <value in [disable, enable]>
+          #     tunnel_encryption: <value in [disable, enable]>
+          #     verify_cert: <value in [disable, enable]>
+          # saml_server: <string>
+          # service: <value in [http, https, tcp-forwarding, ...]>
+          # ssl_algorithm: <value in [high, medium, low, ...]>
+          # ssl_cipher_suites:
+          #   - cipher: <value in [TLS-RSA-WITH-RC4-128-MD5, TLS-RSA-WITH-RC4-128-SHA, TLS-RSA-WITH-DES-CBC-SHA, ...]>
+          #     priority: <integer>
+          #     versions:
+          #       - "tls-1.0"
+          #       - "tls-1.1"
+          #       - "tls-1.2"
+          #       - "tls-1.3"
+          # ssl_dh_bits: <value in [768, 1024, 1536, ...]>
+          # ssl_max_version: <value in [tls-1.0, tls-1.1, tls-1.2, ...]>
+          # ssl_min_version: <value in [tls-1.0, tls-1.1, tls-1.2, ...]>
+          # url_map: <string>
+          # url_map_type: <value in [sub-string, wildcard, regex]>
+          # virtual_host: <string>
+          # saml_redirect: <value in [disable, enable]>
+          # ssl_vpn_web_portal: <string>
+          # application: <list or string>
+          # ssl_renegotiation: <value in [disable, enable]>
+          # h2_support: <value in [disable, enable]>
+          # h3_support: <value in [disable, enable]>
+          # quic:
+          #   ack_delay_exponent: <integer>
+          #   active_connection_id_limit: <integer>
+          #   active_migration: <value in [disable, enable]>
+          #   grease_quic_bit: <value in [disable, enable]>
+          #   max_ack_delay: <integer>
+          #   max_datagram_frame_size: <integer>
+          #   max_idle_timeout: <integer>
+          #   max_udp_payload_size: <integer>
 '''
 
 RETURN = '''
@@ -686,7 +693,8 @@ def main():
                         'type': {'v_range': [['7.0.1', '']], 'choices': ['tcp-forwarding', 'ssh'], 'type': 'str'},
                         'translate-host': {'v_range': [['7.2.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                         'external-auth': {'v_range': [['7.4.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                        'tunnel-encryption': {'v_range': [['7.4.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
+                        'tunnel-encryption': {'v_range': [['7.4.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                        'verify-cert': {'v_range': [['7.6.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
                     },
                     'elements': 'dict'
                 },
